@@ -1,7 +1,7 @@
       SUBROUTINE WZGEES( IWRAP, SELECT, N, A, LDA, SDIM, W, VS,
      $                  LDVS, WORK, LWORK, RWORK, IBWORK, INFO )
 *     .. Scalar Arguments ..
-      INTEGER            IWRAP
+      INTEGER            IWRAP, I
       INTEGER            INFO, LDA, LDVS, LWORK, N, SDIM
 *     .. Array Arguments ..
       INTEGER            IBWORK( * )
